# pandastools: Helper functions for Pandas DataFrames / Series
[![PyPI Latest Release](https://img.shields.io/pypi/v/pandastools.svg)](https://pypi.org/project/pandastools/)
[![Package Status](https://img.shields.io/pypi/status/pandastools.svg)](https://pypi.org/project/pandastools/)
[![License](https://img.shields.io/pypi/l/pandastools.svg)](https://github.com/pandastools-dev/pandastools/blob/master/LICENSE)
[![Travis Build Status](https://travis-ci.org/pandastools-dev/pandastools.svg?branch=master)](https://travis-ci.org/pandastools-dev/pandastools)
[![CodeCov](https://codecov.io/gh/phil65/PandasTools/branch/master/graph/badge.svg)](https://codecov.io/gh/phil65/PandasTools)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyUp](https://pyup.io/repos/github/phil65/PandasTools/shield.svg)](https://pyup.io/repos/github/phil65/PandasTools/)

## What is it?

**PandasTools** is a Python package that provides additional functions for Pandas DataFrames, Series and Indexes via accessors

## Main Features

  - TODO

   [dataframe]: https://phil65.github.io/PandasTools/dataframe.html


## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/phil65/PandasTools

The latest released version are available at the [Python
package index](https://pypi.org/project/pandastools).

```sh
# or PyPI
pip install pandastools
```

## Dependencies
- [pandas](https://pypi.org/project/pandas)


## Installation from sources

This project uses poetry for dependency management and packaging. Install this first.
In the `pandastools` directory (same one where you found this file after
cloning the git repo), execute:

```sh
poetry install
```

## License
[MIT](LICENSE)

## Documentation
The official documentation is hosted on Github Pages: https://phil65.github.io/PandasTools/

## Contributing to pandas [![Open Source Helpers](https://www.codetriage.com/phil65/pandastools/badges/users.svg)](https://www.codetriage.com/phil65/pandastools)

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.

Or maybe through using PandasTools you have an idea of your own or are looking for something in the documentation and thinking ‘this can be improved’...you can do something about it!
